//!/////////////////////////////////////////////////////////////////////////
/// port_definitions.h                                                    //
///                                                                       //
/// Version:     0.8                                                      //
/// Date:        01/09/2010                                               //
/// Author:      Michael Skutek (michael@skutek.de)                       //
///                                                                       //
/// Description: Port Settings (Definitions, Association)                 //
///                                                                       //
/// Platform:    AVR ATmega (tested on ATmega16)                          //
///                                                                       //
///                                                                       //
/// This program is free software: you can redistribute it and/or modify  //
/// it under the terms of the GNU Lesser General Public License as        //
/// published by the Free Software Foundation, either version 3 of the    //
/// License, or (at your option) any later version.                       //
///                                                                       //
/// This program is distributed in the hope that it will be useful,       //
/// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          //
/// GNU Lesser General Public License for more details.                   //
///                                                                       //
/// You should have received a copy of the GNU Lesser General Public      //
/// License along with this program. If not, see                          //
/// <http://www.gnu.org/licenses/>.                                       //
//!/////////////////////////////////////////////////////////////////////////


#ifndef PORT_DEFINITIONS_H_INCLUDED
#define PORT_DEFINITIONS_H_INCLUDED




///Typical Display Pinout (WITHOUT WARRANTY - READ DOCUMENTATION!):

//  Symbol              Pin No.         Description
//
//    Vss                 1               Ground
//    Vdd                 2               Supply Voltage for Logic
//    Vo                  3               Supply Voltage for LCD
//    RS                  4               Register Select (RS=0: Instruction Register, RS=1: Data Register)
//    R/W                 5               Read/Write (R/W=0: write, R/W=1: read)
//    E                   6               Enable
//    D0 to D7          7 to 14           Bi-directional Data Bus
//    BL-                15               Backlight supply terminal (Anode)
//    BL+                16               Backlight supply terminal (Cathode)




///Pin Settings

//LCD
#define LCD_PORT                     PORTD          //Controller Port for LCD Output
#define LCD_DDR                       DDRD          //DDR Register of Controller Port for LCD Output
#define LCD_RS                         PD0          //Pin for RS (Register Select)
#define LCD_RW                         PD1          //Pin for R/W (Read/Write)
//#define LCD_EN                         PD2          //Pin for E (Enable)
#define LCD_EN                         PD2          //Pin for E (Enable)

//#define LCD_BACKLIGHT                  PD3          //Pin for Backlight

//#define LCD_DB4                        PD4          //Pin for D4 (Data, Bit 4)
//#define LCD_DB5                        PD5          //Pin for D5 (Data, Bit 5)
//#define LCD_DB6                        PD6          //Pin for D6 (Data, Bit 6)
//#define LCD_DB7                        PD7          //Pin for D7 (Data, Bit 7)

#define LCD_DB4                        PD4          //Pin for D4 (Data, Bit 4)
#define LCD_DB5                        PD5          //Pin for D5 (Data, Bit 5)
#define LCD_DB6                        PD6          //Pin for D6 (Data, Bit 6)
#define LCD_DB7                        PD7          //Pin for D7 (Data, Bit 7)

#define LCDBL_PORT                   PORTD          //!< Controller Port for Backlight Pin
#define LCDBL_DDR                     DDRD          //!< DDR Register of Controller Port for LCD Backlight
#define LCDBL_CTRL                     PD3          //!< Pin for Backlight


//LED
#define DCF_LED_PORT                 PORTB
#define DCF_LED_DDR                   DDRB
#define DCF_LED_ADDR                   PB1


//Comparator (DCF77 Data)
#define COMP_PORT                    PORTC           //PORTx of Port which is connected to the comparator
#define COMP_PIN                      PINC           //PINx of Port which is connected to the comparator
#define COMP_DDR                      DDRC           //DDR of Port which is connected to the comparator
#define COMP_DATA                      PC2           //used input pin for the comparator


//PON
#define PON_PORT                     PORTC           //Port for PON signal to DCF77 module
#define PON_DDR                       DDRC           //DDR of Port for PON signal to DCF77 module
#define PON_ADDR                       PC3           //Pin which is connected to PON signal of DCF77 module


//I2C
#define I2C_PORT                     PORTC           //Port for I2C Bus
#define I2C_DDR                       DDRC           //DDR of Port for I2C Bus
#define I2C_SDA_ADDR                   PC4           //Pin for SDA
#define I2C_SCL_ADDR                   PC5           //Pin for SCL




#endif // PORT_DEFINITIONS_H_INCLUDED
